@@ -1,4 +1,4 @@
-use crate::{cargo::CargoRanges, sonar};
+use crate::{cargo::Lockfile, sonar};
 use eyre::{Context, Result};
 use rustsec::{Report, Vulnerability};
 use std::{fs::File, path::PathBuf};
@@ -8,17 +8,17 @@ const AUDIT_ENGINE: &str = "audit";
 
 pub struct Audit<'ranges> {
     json: PathBuf,
-    cargo_ranges: &'ranges CargoRanges,
+    lockfile: &'ranges Lockfile,
 }
 
 impl<'ranges> Audit<'ranges> {
-    pub fn new<P>(json: P, cargo_ranges: &'ranges CargoRanges) -> Self
+    pub fn new<P>(json: P, lockfile: &'ranges Lockfile) -> Self
     where
         P: Into<PathBuf>,
     {
         Self {
             json: json.into(),
-            cargo_ranges,
+            lockfile,
         }
     }
 
@@ -31,21 +31,13 @@ impl<'ranges> Audit<'ranges> {
             "{} (see https://github.com/rustsec/advisory-db/blob/main/crates/{}/{}.md)",
             advisory.title, advisory.package, advisory.id
         );
-        let file_path = self.cargo_ranges.cargo_path.to_string_lossy().to_string();
-        let text_range = self
-            .cargo_ranges
-            .dependencies
-            .get(advisory.package.as_str())
-            .and_then(|ranges| ranges.1.as_ref())
-            .or_else(|| {
-                self.cargo_ranges
-                    .dependencies
-                    .get(advisory.package.as_str())
-                    .map(|ranges| &ranges.0)
-            })
-            .map(|range| sonar::TextRange::clone(range))
+        let file_path = self.lockfile.lockfile_path.to_string_lossy().to_string();
+        let dependency = self.lockfile.dependencies.get(advisory.package.as_str());
+        let text_range = dependency
+            .map(|ranges| &ranges.range)
+            .map(sonar::TextRange::clone)
             .unwrap_or_else(|| {
-                error!("failed to find a corresponding text range for this vulnerability. This is probably a bug in `cargo-sonar`, if you can please report an issue, we'd be happy to try and fix it.");
+                error!("failed to find a corresponding text range for this vulnerability. This is probably a bug in `cargo-sonar`, if you can please report an issue at https://gitlab.com/woshilapin/cargo-sonar/-/issues, we'd be happy to try and fix it.");
                 sonar::TextRange {
                     start_line: 1,
                     end_line: 1,
@@ -82,7 +74,12 @@ impl std::convert::TryInto<sonar::Report> for Audit<'_> {
     type Error = eyre::Error;
 
     fn try_into(self) -> Result<sonar::Report> {
-        let file = File::open(&self.json)?;
+        let file = File::open(&self.json).with_context(|| {
+            format!(
+                "failed to open 'cargo-audit' report from '{:?}' file",
+                self.json
+            )
+        })?;
         let report = serde_json::from_reader::<_, Report>(file)
             .context("failed to be parsed as a 'rustsec::report::Report'")?;
         let issues = self.to_issues(report);
