@@ -16,4 +16,6 @@ pub struct Command {
     #[cfg(feature = "clippy")]
     #[clap(long, default_value = "clippy.json")]
     pub clippy_path: PathBuf,
+    #[clap(short, long, default_value = "sonar.json")]
+    pub sonar_path: PathBuf,
 }
