@@ -9,6 +9,8 @@ mod cli;
 mod clippy;
 mod sonar;
 
+use std::fs::File;
+
 use clap::Parser;
 use eyre::{Context as _, Result};
 use tracing::{info, Level};
@@ -39,16 +41,16 @@ fn main() -> Result<()> {
     let options = cli::Command::parse();
 
     #[cfg(feature = "audit")]
-    let cargo_ranges = {
-        let cargo_toml = std::env::current_dir()?.join("Cargo.toml");
-        cargo::CargoRanges::try_from(cargo_toml.as_path())?
+    let lockfile = {
+        use std::env::current_dir;
+        let lockfile_path = current_dir()?.join("Cargo.lock");
+        cargo::Lockfile::try_from(lockfile_path.as_path())?
     };
     let mut sonar_report = sonar::Report::default();
     #[cfg(feature = "audit")]
     if options.audit {
         use crate::audit::Audit;
-        let audit_report: sonar::Report =
-            Audit::new(options.audit_path, &cargo_ranges).try_into()?;
+        let audit_report: sonar::Report = Audit::new(options.audit_path, &lockfile).try_into()?;
         sonar_report.extend(audit_report);
     }
     #[cfg(feature = "clippy")]
@@ -57,7 +59,7 @@ fn main() -> Result<()> {
         let clippy_report: sonar::Report = Clippy::new(options.clippy_path).try_into()?;
         sonar_report.extend(clippy_report);
     }
-    let file = std::fs::File::create("sonar.json").context("failed to create 'sonar.json' file")?;
+    let file = File::create(options.sonar_path).context("failed to create 'sonar.json' file")?;
     info!("{} sonar issues created", sonar_report.len());
     #[cfg(not(debug_assertions))]
     let writer = serde_json::to_writer;
