@@ -2,6 +2,7 @@ use serde::Serialize;
 
 #[derive(Debug, Serialize)]
 #[serde(rename_all = "SCREAMING_SNAKE_CASE")]
+#[allow(dead_code)]
 pub enum Severity {
     Blocker,
     Critical,
@@ -47,17 +48,17 @@ pub struct Issue {
 }
 
 #[derive(Debug, Default, Serialize)]
-pub struct Issues {
+pub struct Report {
     issues: Vec<Issue>,
 }
 
-impl Issues {
+impl Report {
     pub fn len(&self) -> usize {
         self.issues.len()
     }
 }
 
-impl FromIterator<Issue> for Issues {
+impl FromIterator<Issue> for Report {
     fn from_iter<T: IntoIterator<Item = Issue>>(iter: T) -> Self {
         Self {
             issues: iter.into_iter().collect(),
@@ -65,7 +66,7 @@ impl FromIterator<Issue> for Issues {
     }
 }
 
-impl IntoIterator for Issues {
+impl IntoIterator for Report {
     type Item = Issue;
 
     type IntoIter = std::vec::IntoIter<Self::Item>;
@@ -75,8 +76,8 @@ impl IntoIterator for Issues {
     }
 }
 
-impl Extend<Issue> for Issues {
+impl Extend<Issue> for Report {
     fn extend<T: IntoIterator<Item = Issue>>(&mut self, iter: T) {
-        self.issues.extend(iter.into_iter())
+        self.issues.extend(iter)
     }
 }
